Crate frunk_utils
source ·Expand description
Utilities for working with frunk.
Re-exports
Modules
Structs
- The Func trait from frunk doesn’t take
selfas a parameter tocallso there isn’t an easy way to get context from the surrounding scope. Here we define our ownPolywrapper andFunctrait that does takeselfas a parameter so the caller can include whatever context they need.
Traits
- Convenience functions for the caller to map between similarly-shaped types implementing [Generic] without having to explicitly call [Generic::from] and [Generic::into]
- Convenience functions for the caller to map between similarly-shaped types implementing [LabelledGeneric] without having to explicitly call [LabelledGeneric::from] and [LabelledGeneric::into]